@@ -1,4 +1,4 @@
-# HiQ version 1.1.0
+# HiQ version 1.1.4
 #
 # Copyright (c) 2022, Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/ 
@@ -7,6 +7,10 @@
 import psutil
 
 
+def get_memory_gb() -> float:
+    return psutil.Process().memory_info().rss / (1024 * 1024 * 1024)
+
+
 def get_memory_mb() -> float:
     """Get RSS in MB unit
 
